import { BehaviorOptions, Distribution, DistributionProps, ErrorResponse, GeoRestriction, HttpVersion, IOrigin, PriceClass, SecurityPolicyProtocol, SSLMethod } from "aws-cdk-lib/aws-cloudfront";
import { Certificate } from "aws-cdk-lib/aws-certificatemanager";
import { IBucket } from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { BehaviorBuilder, WebsiteDefaultsProps } from "./behavior-builder";
import { DomainName } from "../../aws-route53";
export declare class DistributionBuilder {
    protected props: DistributionProps;
    protected defaultBehaviorBuilder: BehaviorBuilder;
    protected additionalBehaviorBuilders: Record<string, BehaviorBuilder>;
    constructor(defaultBehaviorBuilder: BehaviorBuilder);
    defaultBehavior(): BehaviorBuilder;
    additionalBehaviors(additionalBehaviors?: Record<string, BehaviorOptions>): DistributionBuilder;
    additionalBehavior(pattern: string, origin: IOrigin): BehaviorBuilder;
    certificate(certificate?: Certificate): DistributionBuilder;
    comment(comment?: string): DistributionBuilder;
    defaultRootObject(defaultRootObject?: string): DistributionBuilder;
    domainNames(domainNames?: string[]): DistributionBuilder;
    domainName(domainName: string | DomainName): DistributionBuilder;
    enabled(enabled?: boolean): DistributionBuilder;
    enableIpv6(enableIpv6?: boolean): DistributionBuilder;
    enableLogging(enableLogging?: boolean): DistributionBuilder;
    geoRestriction(geoRestriction?: GeoRestriction): DistributionBuilder;
    httpVersion(httpVersion?: HttpVersion): DistributionBuilder;
    logBucket(logBucket?: IBucket): DistributionBuilder;
    logIncludesCookies(logIncludesCookies?: boolean): DistributionBuilder;
    logFilePrefix(logFilePrefix?: string): DistributionBuilder;
    priceClass(priceClass?: PriceClass): DistributionBuilder;
    webAclId(webAclId?: string): DistributionBuilder;
    errorResponses(errorResponses?: ErrorResponse[]): DistributionBuilder;
    errorResponse(errorResponse: ErrorResponse): DistributionBuilder;
    minimumProtocolVersion(minimumProtocolVersion?: SecurityPolicyProtocol): DistributionBuilder;
    sslSupportMethod(sslSupportMethod?: SSLMethod): DistributionBuilder;
    defaults(): DistributionBuilder;
    websiteDefaults(props: WebsiteDefaultsProps): DistributionBuilder;
    build(): DistributionProps;
    toDistribution(scope: Construct, id: string): Distribution;
    static fromOrigin(origin: IOrigin): DistributionBuilder;
}
